<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

define( 'SILION_PARENT_DIR', get_template_directory() );
define( 'SILION_CHILD_DIR', get_stylesheet_directory() );
define( 'SILION_INCLUDES_DIR', SILION_PARENT_DIR . '/framework' );
define( 'SILION_CSS_DIR', SILION_PARENT_DIR . '/css' );
define( 'SILION_JS_DIR', SILION_PARENT_DIR . '/js' );
define( 'SILION_LANGUAGES_DIR', SILION_PARENT_DIR . '/languages' );
define( 'SILION_WIDGETS_DIR', SILION_INCLUDES_DIR . '/widgets' );
define( 'SILION_ELEMENTOR_DIR', SILION_INCLUDES_DIR . '/elementor' );
define( 'SILION_ELEMENTOR_WIDGETS_DIR', SILION_ELEMENTOR_DIR . '/widgets' );

/**
 * Define URL Location Constants
 */
define( 'SILION_PARENT_URL', get_template_directory_uri() );
define( 'SILION_CHILD_URL', get_stylesheet_directory_uri() );
define( 'SILION_INCLUDES_URL', SILION_PARENT_URL . '/framework' );
define( 'SILION_CSS_URL', SILION_PARENT_URL . '/css' );
define( 'SILION_JS_URL', SILION_PARENT_URL . '/js' );
define( 'SILION_LANGUAGES_URL', SILION_PARENT_URL . '/languages' );
define( 'SILION_WIDGETS_URL', SILION_INCLUDES_URL . '/widgets' );
define( 'SILION_ELEMENTOR_URL', SILION_INCLUDES_URL . '/elementor' );
define( 'SILION_ELEMENTOR_WIDGETS_URL', SILION_ELEMENTOR_URL . '/widgets' );


if(class_exists( 'Menu_Item_Custom_Fields' )){
  require_once SILION_INCLUDES_DIR  . '/menu-item-custom-fields.php';
}

require_once SILION_INCLUDES_DIR . '/meta-box.php';
require_once SILION_INCLUDES_DIR . '/silion_bootstrap_navwalker.php';
require_once SILION_INCLUDES_DIR . '/import.php';
require_once SILION_INCLUDES_DIR . '/customize.php';

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
  $content_width = 900;
}

// Set up theme support
function silion_setup() {

  add_theme_support( 'post-thumbnails' );
  add_image_size( 'silion-thumb', 370, 300, true );
  add_theme_support( 'automatic-feed-links' );
  add_theme_support( 'title-tag' );
  add_theme_support( 'custom-header');
  add_theme_support( 'custom-background');
  add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
  add_theme_support( 'custom-logo' );
  // This theme uses wp_nav_menu() in two locations.
  register_nav_menus( array(
    'primary'    => esc_html__( 'Primary Menu', 'silion' ),
  ) );
  add_theme_support( 'editor-styles' );
  add_editor_style( 'css/style-editor.css' );
  load_theme_textdomain( 'silion', get_template_directory() . '/languages' );

}
add_action( 'after_setup_theme', 'silion_setup' );

// Theme Scripts & Styles
function silion_scripts_styles() {

  wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
  wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.min.css');
  wp_enqueue_style( 'line-awesome', get_template_directory_uri().'/css/line-awesome.min.css');
	wp_enqueue_style( 'silion-default', get_template_directory_uri().'/css/style.css');
  wp_enqueue_style( 'silion', get_stylesheet_uri() );
  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {

    // enqueue the javascript that performs in-link comment reply fanciness
    wp_enqueue_script( 'comment-reply' ); 

  }
  wp_enqueue_script('jquery-ui-core');
 	wp_enqueue_script('masonry');
  wp_enqueue_script('bootstrap', get_template_directory_uri().'/js/bootstrap.min.js',array('jquery'),false,true);
  $key = get_theme_mod('map_api');
  if(isset($key) and $key !=''){
    wp_enqueue_script("silion-googleapis", "//maps.googleapis.com/maps/api/js?key=".get_theme_mod('map_api'),array('jquery'),false,true);
    wp_enqueue_script( 'silion-gmap3', get_template_directory_uri().'/js/gmap3.min.js', array( 'jquery' ), '1.0', true );
  }
  
  wp_enqueue_script('silion-script', get_template_directory_uri().'/js/script.js',array('jquery'),false,true);

}
add_action( 'wp_enqueue_scripts', 'silion_scripts_styles' );

add_action( 'wp_enqueue_scripts', 'silion_add_frontend_ajax_javascript_file' );
function silion_add_frontend_ajax_javascript_file()
{
  wp_enqueue_script( 'silion_ajax_custom_script',  get_template_directory_uri().'/js/ajax-javascript.js', array('jquery') );
  wp_localize_script( 'silion_ajax_custom_script', 'ajaxurl', array( 'ajaxurl' => admin_url( 'admin-ajax.php' )));

}

function silion_load_custom_wp_admin_style() {

  wp_register_style( 'line-awesome', get_template_directory_uri().'/css/line-awesome.min.css', false, '1.0.0' );
  wp_enqueue_style( 'line-awesome' );

}
add_action( 'admin_enqueue_scripts', 'silion_load_custom_wp_admin_style' );

/* Function which displays your post date in time ago format */
function silion_time_ago() {

  return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ).' '.esc_html__( 'ago','silion' );

}

/**WOOCOMMERCE**/
remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20, 0);
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'silion_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'silion_wrapper_end', 10);

add_filter('loop_shop_columns', 'silion_loop_columns', 999);
if (!function_exists('silion_loop_columns')) {
  function silion_loop_columns() {
    return 3; // 3 products per row
  }
}
add_filter('woocommerce_show_page_title', 'silion_show_page_title', 999);
if (!function_exists('silion_show_page_title')) {
  function silion_show_page_title() {
    return false; // 3 products per row
  }
}

add_filter( 'woocommerce_output_related_products_args', 'silion_change_number_related_products' );

function silion_change_number_related_products( $args ) {
 
 $args['posts_per_page'] = 3;
 $args['columns'] = 3; //change number of upsells here
 return $args;
}

// Register Elementor Locations
function silion_register_elementor_locations( $elementor_theme_manager ) {

	$elementor_theme_manager->register_all_core_location();

};
add_action( 'elementor/theme/register_locations', 'silion_register_elementor_locations' );

function silion_excerpt($limit = 30) {
 
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;

}

function silion_elementor_categories() {

    $output     = array();
    $categories = get_categories();
    $output[  ] = 'Select';
    foreach ( $categories as $category ) {
        $output[ $category->term_id ] = $category->name;
    }

    return $output;
}


/**
 * Display custom color CSS.
 */
function silion_colors_css_wrap() {
    global  $wp_query;
    $main_color = get_theme_mod( 'main_color','#6228b1'); 
    $hover_color = get_theme_mod( 'hover_color','#FF3672'); 
    $header_img = get_header_image();
    $logo_dimensions = get_theme_mod('logo_dimensions');
?>
    <style type="text/css" id="custom-theme-colors">
        <?php 
            $css="
              .sidebar .popular-widget ul.popular-list li .side-content h2 a:hover, p.auth-paragraph a:hover, .blog-box .blog-post h2 a:hover, .single-post__tags a:hover, .other-posts__prev:hover i, .other-posts__next:hover i, .other-posts__prev:hover h2, .other-posts__next:hover h2, .comment-area-box > ul li .comment-box .comment-content a:hover,.comment-area-box > ul li .comment-box .comment-content h4 a,.tagcloud a, .tag-list li a,.widget_recent_entries ul li a:hover, .widget_recent_comments ul li a:hover, .widget_archive ul li a:hover, .widget_categories ul li a:hover, .widget_meta ul li a:hover, .widget_pages ul li a:hover, .widget_rss ul li a:hover, .widget_nav_menu ul li a:hover, .product-categories li a:hover, .widget_featured_posts ul li a:hover,.dropdown > li.current-menu-item > a, .image-block .services-content span, .text-btn, .testimonial-post h3 {
                color: $main_color;
              }
              .navbar-nav > li > a.active,
              .navbar-nav > li > a:hover{
                color: $hover_color !important; 
              }
              footer .up-footer .footer-widget ul.social-list li a:hover, table td#today, .tagcloud a:hover, .tag-list li a:hover, input[type='submit']:hover, .btn-default:hover, .owl-theme .owl-controls .owl-buttons div:hover{
                background: $main_color;
              }
              header.active{
                background: $main_color !important;
              }
              .search-widget button, .sidebar .widget > h2:before{
                background: $hover_color;
              }
              .text-btn:hover, .testimonial-post span,.widget_recent_entries ul li:before, .widget_recent_comments ul li:before, .widget_archive ul li:before, .widget_categories ul li:before, .widget_meta ul li:before, .widget_pages ul li:before, .widget_nav_menu ul li:before, .product-categories li:before, .widget_featured_posts ul li:before, .sidebar .popular-widget ul.popular-list li .side-content span, .single-post__tags:before, footer .up-footer .footer-widget ul.quick-list li:before, section.portfolio-section ul.filter li a:hover,
      section.portfolio-section ul.filter li a.active{
                color: $hover_color;
              }
              .btn-default, .pagination-list li span, .pagination-list li a:hover, .pagination-list li .current{
                border-color: $hover_color;
              }
              .navbar-nav > li.active > a, .navbar-nav > li.current-menu-ancestor > a, .dropdown > li.current-menu-item > a, .dropdown > li > a:hover{
                color: $hover_color !important;
              }
              
              .btn-default:hover, .inner-error .btn-default, .pagination-list li span, .pagination-list li a:hover, .pagination-list li .current{
                background: $hover_color;
              }
              .navbar-nav > li > a.active,
              .navbar-nav > li > a:hover,.text-btn:hover, .navbar-nav > li.active > a, .navbar-nav > li.current-menu-ancestor > a, section.portfolio-section ul.filter li a:hover,
      section.portfolio-section ul.filter li a.active{
                border-bottom-color: $hover_color;
              }
              input[type='text']:focus, input[type='email']:focus,input[type='password']:focus,input[type='search']:focus,input[type='number']:focus,input[type='url']:focus, textarea:focus{
                border-color: $main_color;
              }
              @media(max-width: 991px){
                .dropdown li a:before{
                  color: $hover_color;
                }
              }
            ";

            $id= $wp_query->get_queried_object_id();
            $bg = get_post_meta($wp_query->get_queried_object_id(), "_silion_banner", true);
            if($bg!=''){
                $css .= ".page-id-$id section.page-banner-section{
                    background: url($bg) !important;
                }";
            }
            if($header_img!=''){
              $css .= "section.page-banner-section{
                    background-image: url($header_img) !important;
                }";
            }

            if($logo_dimensions){
              $css .="
                .navbar a.navbar-brand img{
                  max-width: ".$logo_dimensions['max-width'].";
                }
              ";
            }
            echo do_shortcode($css);
        ?>
    </style>
<?php }
add_action( 'wp_head', 'silion_colors_css_wrap' );


//pagination
function silion_pagination($prev = '', $next = '', $pages='') {

  global $wp_query, $wp_rewrite;
  $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
  if($pages==''){
    global $wp_query;
    $pages = $wp_query->max_num_pages;
    if(!$pages){
      $pages = 1;
    }
    }if(is_front_page() and !is_home()) {
    $curent = (get_query_var('page')) ? get_query_var('page') : 1;
  } else {
    $curent = (get_query_var('paged')) ? get_query_var('paged') : 1;
  }
    $pagination = array(
      'base'      => str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
      'format'    => '',
      'current'     => max( 1, $curent),
      'total'     => $pages,
      'prev_text' => $prev,
      'next_text' => $next,
      'type'      => 'list',
      'end_size'    => 2,
      'mid_size'    => 1
  );
    $return =  paginate_links( $pagination );
  echo str_replace( "<ul class='page-numbers'>", '<ul class="pagination-list">', $return );
  
}


add_filter('wp_list_categories', 'silion_span_cat_count');
add_filter('get_archives_link', 'silion_span_archives_count');
function silion_span_archives_count($links) {

  $links = str_replace('</a>&nbsp;(', '</a> <span class="archiveCount">(', $links);
  $links = str_replace(')', ')</span>', $links);
  return $links;

}

function silion_span_cat_count($links) {

  $links = str_replace('</a> (', '</a> <span>', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;

}


function silion_load_portfolio_grid(){
  global $silion_options;
  $response = '';
  $cat = $_POST['cat'];
  $order = $_POST['order'];
  $page = $_POST['page'];
  $thumb = $_POST['thumb'];

  if(isset($cat) and $cat!='all'){
    $args = array('post_type' => 'portfolio','post_status' => 'publish', 'posts_per_page' => $order, 'paged'=>$page, 'tax_query' => array(
    array(
      'taxonomy' => 'portfolio_category',
      'field'    => 'slug',
      'terms'    => $cat,
    ),
  ));
  }else{
    $args = array('post_type' => 'portfolio', 'post_status' => 'publish', 'posts_per_page' => $order, 'paged'=>$page);
  }

  $portfolio = new WP_Query($args);
?>  

<?php 
      if($portfolio->have_posts()) :
             $i=1; while($portfolio->have_posts()) : $portfolio->the_post(); 
    ?>
  
    <?php
      $item_classes = '';
      $item_skill = '';
      $item_cats = get_the_terms(get_the_ID(), 'portfolio_tag');
      $i=1; foreach((array)$item_cats as $item_cat){
          if(count($item_cat)>0){
              $item_classes .= $item_cat->slug . ' ';
              
          }

          if($i==1){
              $item_skill .= $item_cat->name;
          }else{
              $item_skill .= ' / '. $item_cat->name;
          }
          $custom_class = get_post_meta(get_the_ID(), '_silion_project_class', true);
            if($custom_class!=''){
              $item_classes .= ' '.$custom_class;
          }
      $i++; }
    ?>
    <div class="item project-post <?php echo esc_attr($item_classes); ?>">
          
      <?php if(has_post_thumbnail()){ ?>
        <div class="project-gal">
          <?php the_post_thumbnail($thumb); ?>
        </div>
      <?php } ?>
      
      <div class="hover-box">
        
        <h2 class="heading2"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
        <ul class="project-tags">
          <li><?php echo esc_html($item_skill);?></li>
          
        </ul>
      </div>
      
    </div>

  <?php $i++; endwhile; ?>
  <?php endif; ?>
  <?php wp_reset_postdata(); ?>

<?php 
  echo do_shortcode($response);
  die();
}
add_action('wp_ajax_silion_load_portfolio_grid', 'silion_load_portfolio_grid');
add_action('wp_ajax_nopriv_silion_load_portfolio_grid', 'silion_load_portfolio_grid');



/* Header */
function silion_header() {

    global $wp_query;
    $header_layout = get_post_meta($wp_query->get_queried_object_id(), '_silion_header_layout', true);
    if($header_layout!='' and $header_layout!='1'){
        $header_layout = $header_layout;
    }else{ 
    $header_layout = get_theme_mod( 'header_layout', '1' );
    }

    if($header_layout!='' and $header_layout!='1'){
      $header_layout = $header_layout;
    }else{
      
        $header_layout = '1';
      
    }
   
   get_template_part('template-parts/header', $header_layout);
}

function silion_footer() {

    global $wp_query;
    $footer_layout = get_post_meta($wp_query->get_queried_object_id(), '_silion_footer_layout', true);
    if($footer_layout!='' and $footer_layout!='1'){
        $footer_layout = $footer_layout;
    }else{ 
      $footer_layout = get_theme_mod( 'footer_layout', '1' );
    }

    if($footer_layout!='' and $footer_layout!='1'){
      $footer_layout = $footer_layout;
    }else{
      
        $footer_layout = '1';
      
    }
    
   get_template_part('template-parts/footer', $footer_layout);

}

/*
Register Fonts
*/
function silion_fonts_url() {

  $font_url = '';
  
  /*
  Translators: If there are characters in your language that are not supported
  by chosen font(s), translate this to 'off'. Do not translate into your own language.
   */
  if ( 'off' !== _x( 'on', 'Google font: on or off', 'silion' ) ) {
    $font_url = add_query_arg( 'family', urlencode( 'Hind:300,400,500,600,700|Catamaran:300,300i,400,400i,500,500i,600,600i,700,800,900|Poppins:300,300i,400,400i,500,500i,600,600i,700,800,900' ), "//fonts.googleapis.com/css" );
  }
  return $font_url;
}


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function silion_widgets_init() {

  register_sidebar( array(
    'name'          => esc_html__( 'Blog sidebar', 'silion' ),
    'id'            => 'sidebar-1',
    'description'   => esc_html__( 'Add widgets here to appear in your blog sidebar.', 'silion' ),
    'before_widget' => '<section id="%1$s" class="widget %2$s">',
    'after_widget'  => '</section>',
    'before_title'  => '<h2 class="heading2 title-sidebar">',
    'after_title'   => '</h2>',
  ) );
  
  register_sidebar( array(
    'name'          => esc_html__( 'Footer 1', 'silion' ),
    'id'            => 'footer-1',
    'description'   => esc_html__( 'Add widgets here to appear in your Footer 1.', 'silion' ),
    'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h2 class="heading2 title-sidebar">',
    'after_title'   => '</h2>',
  ) );
  
  register_sidebar( array(
    'name'          => esc_html__( 'Footer 2', 'silion' ),
    'id'            => 'footer-2',
    'description'   => esc_html__( 'Add widgets here to appear in your Footer 2.', 'silion' ),
    'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h2 class="heading2 title-sidebar">',
    'after_title'   => '</h2>',
  ) );
  
  register_sidebar( array(
    'name'          => esc_html__( 'Footer 3', 'silion' ),
    'id'            => 'footer-3',
    'description'   => esc_html__( 'Add widgets here to appear in your Footer 3.', 'silion' ),
    'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h2 class="heading2 title-sidebar">',
    'after_title'   => '</h2>',
  ) );
  
  register_sidebar( array(
    'name'          => esc_html__( 'Footer 4', 'silion' ),
    'id'            => 'footer-4',
    'description'   => esc_html__( 'Add widgets here to appear in your Footer 4.', 'silion' ),
    'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h2 class="heading2 title-sidebar">',
    'after_title'   => '</h2>',
  ) );
  
  
}
add_action( 'widgets_init', 'silion_widgets_init' );

/*
Enqueue scripts and styles.
*/
function silion_font_scripts() {
  
  wp_enqueue_style( 'silion-fonts', silion_fonts_url(), array(), '1.0.0' );
  
}
add_action( 'wp_enqueue_scripts', 'silion_font_scripts' );

function silion_get_comment_depth( $my_comment_id ) {

  $depth_level = 0;
  while( $my_comment_id > 0  ) { // if you have ideas how we can do it without a loop, please, share it with us in comments
    $my_comment = get_comment( $my_comment_id );
    $my_comment_id = $my_comment->comment_parent;
    $depth_level++;
  }
  return $depth_level;
  
}

//Custom comment List:
function silion_theme_comment($comment, $args, $depth) {
    
  $GLOBALS['comment'] = $comment; ?>
  <!--=======  COMMENTS =========-->

  <li <?php comment_class(''); ?> id="comment-<?php comment_ID() ?>" >

    <div class="comment-box">
      <?php if($comment->user_id!='0' and get_user_meta($comment->user_id, '_silion_avatar' ,true)!=''){ ?>
        <?php $image = get_user_meta($comment->user_id, '_silion_avatar' ,true); ?>
        <img src="<?php echo esc_attr($image); ?>" />
      <?php }else{ ?>
        <?php echo get_avatar($comment); ?>
      <?php } ?>
        <div class="comment-content">
            <h4><?php printf(esc_html__('%s','silion'), get_comment_author_link()) ?> </h4>
            <?php if(get_user_meta(get_the_author_meta('ID'), '_silion_user_address' ,true)!=''){ ?>
            <span class="reviews-list__item-location">
              <?php echo get_user_meta($comment->user_id, '_silion_user_address' ,true); ?>
            </span>
          <?php } ?>
            <?php comment_reply_link( array_merge($args, array(
              'reply_text' => ' | <i class="la la-mail-forward"></i>'.esc_html__('Reply', 'silion'),
              'depth'      => $depth,
              'max_depth'  => $args['max_depth']
              )
            )); ?>
           
            <span class="date-comm"><?php printf(esc_html__('%1$s','silion'), get_comment_date()) ?></span>
            <?php comment_text() ?>
             <?php if ($comment->comment_approved == '0') : ?>
               <em><?php esc_html_e('Your comment is awaiting moderation.','silion') ?></em>
               <br />
            <?php endif; ?>
        </div>
    </div>

<?php
}


function silion_excerpt_more( $more ) {
  return '...';
}
add_filter( 'excerpt_more', 'silion_excerpt_more' );

/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme construct for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

require_once get_template_directory() . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'silion_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function silion_register_required_plugins() {
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
        // This is an example of how to include a plugin from a private repo in your theme.

        array(            
            'name'               => esc_html__( 'QK Elementor Elements', 'silion' ), 
            'slug'               => 'qk-elementor', 
            'source'             => get_template_directory() . '/framework/plugins/qk-elementor.zip', 
            'required'           => true, 
        ),array(            
            'name'               => esc_html__('QK Register Post Type', 'silion' ), // The plugin name.
            'slug'               => 'qk-post_type', // The plugin slug (typically the folder name).
            'source'             => get_template_directory() . '/framework/plugins/qk-post_type.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
        
        // This is an example of how to include a plugin from the WordPress Plugin Repository.
    
       array(
            'name'      => esc_html__( 'Kirki', 'silion' ),
            'slug'      => 'kirki',
            'required'  => true,
        ), array(
            'name'      => esc_html__( 'Elementor Page Builder', 'silion' ),
            'slug'      => 'elementor',
            'required'  => true,
        ),array(
            'name'      => esc_html__( 'CMB2', 'silion' ),
            'slug'      => 'cmb2',
            'required'  => true,
        ),array(
            'name'      => esc_html__( 'Contact Form 7', 'silion' ),
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),array(
            'name'      => esc_html__( 'One Click Demo Import', 'silion' ),
            'slug'      => 'one-click-demo-import',
            'required'  => true,
        )
    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins', 'silion' ),
            'menu_title'                      => esc_html__( 'Install Plugins', 'silion' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s', 'silion' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'silion' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'silion' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'silion' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'silion' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'silion' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'silion' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'silion' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'silion' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'silion' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'silion' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'silion' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer', 'silion' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'silion' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'silion' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );
    tgmpa( $plugins, $config );
}
